@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #define _GNU_SOURCE
 
 /* must be first because of a problem with linux/netlink.h */
@@ -80,37 +84,72 @@
 #include "nl80211_listener/nl80211_listener.h"
 
 /* definitions */
+
+/**
+ * nl80211 configuration
+ */
 struct _nl80211_config {
+  /*! interval between two series of netlink probes */
   uint64_t interval;
 };
 
-enum _nl80211_cfg_idx {
-  IDX_INTERVAL,
-  IDX_INTERFACES,
-};
-
-enum _if_query {
-  QUERY_START       = 0,
-  QUERY_GET_IF      = 0,
-  QUERY_GET_WIPHY   = 1,
-  QUERY_GET_SURVEY  = 2,
-  QUERY_GET_MPP     = 3,
-  QUERY_GET_STATION = 4,
-  QUERY_END         = 5,
-
-  QUERY_GET_FAMILY  = 6,
-
-  QUERY_COUNT,
-};
-
-static struct {
+/**
+ * definition of a query to the nl80211 subsystem
+ */
+struct _nl80211_query {
+  /*! netlink command that should be queried later */
   uint8_t cmd;
 
+  /**
+   * Callback to send query
+   * @param nl netlink handler
+   * @param nl_msg netlink message header
+   * @param hdr generic message header
+   * @param interf netlink interface
+   */
   void (* send)(struct os_system_netlink *nl, struct nlmsghdr *nl_msg,
       struct genlmsghdr *hdr, struct nl80211_if *interf);
-  void (* process)(struct nl80211_if *interf, struct nlmsghdr*);
+
+  /**
+   * Callback to process incoming netlink data
+   * @param interf netlink interface
+   * @param hdr netlink message header
+   */
+  void (* process)(struct nl80211_if *interf, struct nlmsghdr *hdr);
+
+  /**
+   * Finalize the processing of the netlink query
+   * @param interf netlink interface
+   */
   void (* finalize)(struct nl80211_if *interf);
-} _if_query_ops[QUERY_COUNT] =
+};
+
+/**
+ * Index number for nl80211 configuration entries
+ */
+enum _nl80211_cfg_idx {
+  IDX_INTERVAL,  //!< IDX_INTERVAL
+  IDX_INTERFACES,//!< IDX_INTERFACES
+};
+
+/**
+ * index numbers for netlink queries done by listener
+ */
+enum _if_query {
+  QUERY_START       = 0,//!< QUERY_START
+  QUERY_GET_IF      = 0,//!< QUERY_GET_IF
+  QUERY_GET_WIPHY   = 1,//!< QUERY_GET_WIPHY
+  QUERY_GET_SURVEY  = 2,//!< QUERY_GET_SURVEY
+  QUERY_GET_MPP     = 3,//!< QUERY_GET_MPP
+  QUERY_GET_STATION = 4,//!< QUERY_GET_STATION
+  QUERY_END         = 5,//!< QUERY_END
+
+  QUERY_GET_FAMILY  = 6,//!< QUERY_GET_FAMILY
+
+  QUERY_COUNT,          //!< QUERY_COUNT
+};
+
+static struct _nl80211_query _if_query_ops[QUERY_COUNT] =
 {
     [QUERY_GET_IF] = {
         NL80211_CMD_NEW_INTERFACE,
@@ -146,7 +185,7 @@ static void _nl80211_if_remove(struct nl80211_if *);
 static void _cb_config_changed(void);
 static void _cb_if_config_changed(void);
 
-static void _cb_transmission_event(void *);
+static void _cb_transmission_event(struct oonf_timer_instance *);
 static void _trigger_next_netlink_query(void);
 
 static void _cb_nl_message(struct nlmsghdr *hdr);
@@ -264,7 +303,7 @@ _early_cfg_init(void) {
  */
 static int
 _init(void) {
-  if (os_system_netlink_add(&_netlink_handler, NETLINK_GENERIC)) {
+  if (os_system_linux_netlink_add(&_netlink_handler, NETLINK_GENERIC)) {
     return -1;
   }
 
@@ -293,9 +332,15 @@ _cleanup(void) {
 
   oonf_timer_stop(&_transmission_timer);
   oonf_timer_remove(&_transmission_timer_info);
-  os_system_netlink_remove(&_netlink_handler);
+  os_system_linux_netlink_remove(&_netlink_handler);
 }
 
+/**
+ * Add a layer2 destination to the database
+ * @param l2neigh layer2 neighbor
+ * @param dstmac destination mac address
+ * @return layer2 destination
+ */
 struct oonf_layer2_destination *
 nl80211_add_dst(struct oonf_layer2_neigh *l2neigh, const struct netaddr *dstmac) {
   struct oonf_layer2_destination *dst;
@@ -356,6 +401,11 @@ nl80211_change_l2neigh_data(struct oonf_layer2_neigh *l2neigh,
   return oonf_layer2_change_value(&l2neigh->data[idx], _layer2_origin, value);
 }
 
+/**
+ * Get a nl80211 interface from tree
+ * @param name interface name
+ * @return nl80211 interface, NULL if not found
+ */
 static struct nl80211_if *
 _nl80211_if_get(const char *name) {
   struct nl80211_if *interf;
@@ -363,6 +413,11 @@ _nl80211_if_get(const char *name) {
   return avl_find_element(&_nl80211_if_tree, name, interf, _node);
 }
 
+/**
+ * Add a nl80211 interface to the tree
+ * @param name interface name
+ * @return nl80211 interface, NULL if out of memory
+ */
 static struct nl80211_if *
 _nl80211_if_add(const char *name) {
   struct nl80211_if *interf;
@@ -408,6 +463,10 @@ _nl80211_if_add(const char *name) {
   return interf;
 }
 
+/**
+ * Remove a nl80211 interface from tree
+ * @param interf nl80211 interface
+ */
 static void
 _nl80211_if_remove(struct nl80211_if *interf) {
   avl_remove(&_nl80211_if_tree, &interf->_node);
@@ -442,15 +501,20 @@ _cb_if_config_changed(void) {
 
 /**
  * Transmit the next netlink command to nl80211
- * @param ptr unused
+ * @param ptr timer instance that fired
  */
 static void
-_cb_transmission_event(void *ptr __attribute__((unused))) {
+_cb_transmission_event(struct oonf_timer_instance *ptr __attribute__((unused))) {
   if (!_current_query_in_progress) {
     _trigger_next_netlink_query();
   }
 }
 
+/**
+ * Send a netlink message to the nl80211 subsystem
+ * @param interf nl80211 interface for message
+ * @param query query id
+ */
 static void
 _send_netlink_message(struct nl80211_if *interf, enum _if_query query) {
   struct genlmsghdr *hdr;
@@ -483,9 +547,12 @@ _send_netlink_message(struct nl80211_if *interf, enum _if_query query) {
     _if_query_ops[query].send(&_netlink_handler, _nl_msg, hdr, interf);
   }
 
-  os_system_netlink_send(&_netlink_handler, _nl_msg);
+  os_system_linux_netlink_send(&_netlink_handler, _nl_msg);
 }
 
+/**
+ * Proceed to next query
+ */
 static void
 _get_next_query(void) {
   if (avl_is_empty(&_nl80211_if_tree)) {
@@ -515,6 +582,7 @@ _get_next_query(void) {
       /* commit interface data */
       if (_current_query_if->ifdata_changed) {
         oonf_layer2_net_remove(_current_query_if->l2net, _layer2_old_origin);
+        oonf_layer2_net_commit(_current_query_if->l2net);
         _current_query_if->ifdata_changed = false;
       }
 
@@ -525,6 +593,9 @@ _get_next_query(void) {
   }
 }
 
+/**
+ * Trigger the next netlink query
+ */
 static void
 _trigger_next_netlink_query(void) {
   if (!_nl80211_id || !_nl80211_multicast_group) {
@@ -587,6 +658,11 @@ _cb_nl_message(struct nlmsghdr *hdr) {
   }
 }
 
+/**
+ * Callback triggered when a netlink message failes
+ * @param seq sequence number
+ * @param error error code
+ */
 static void
 _cb_nl_error(uint32_t seq __attribute((unused)), int error __attribute((unused))) {
   OONF_DEBUG(LOG_NL80211, "seq %u: Received error %d", seq, error);
@@ -595,6 +671,9 @@ _cb_nl_error(uint32_t seq __attribute((unused)), int error __attribute((unused))
   }
 }
 
+/**
+ * Callback triggered when one or more netlink messages time out
+ */
 static void
 _cb_nl_timeout(void) {
   OONF_DEBUG(LOG_NL80211, "Received timeout");
@@ -606,6 +685,10 @@ _cb_nl_timeout(void) {
   }
 }
 
+/**
+ * Callback triggered when a netlink message is done
+ * @param seq sequence number
+ */
 static void
 _cb_nl_done(uint32_t seq __attribute((unused))) {
   OONF_DEBUG(LOG_NL80211, "%u: Received done", seq);
