@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #include "common/common_types.h"
 #include "config/cfg_schema.h"
 #include "core/oonf_logging.h"
@@ -66,7 +70,7 @@ struct _domain_parameters {
   char mpr_name[NHDP_DOMAIN_MPR_MAXLEN];
 
   /*! routing willingness */
-  uint8_t mpr_willingness;
+  int32_t mpr_willingness;
 };
 
 /**
@@ -77,7 +81,7 @@ struct _generic_parameters {
   char flooding_mpr_name[NHDP_DOMAIN_MPR_MAXLEN];
 
   /*! routing willingness */
-  uint8_t mpr_willingness;
+  int32_t mpr_willingness;
 };
 
 /* prototypes */
@@ -97,9 +101,9 @@ static int _cb_validate_domain_section(const char *section_name,
 /* subsystem definition */
 static struct cfg_schema_entry _nhdp_entries[] = {
   CFG_MAP_STRING_ARRAY(_generic_parameters, flooding_mpr_name, "mpr", "*",
-      "ID of the mpr algorithm used for this domain. '"CFG_DOMAIN_NO_MPR"'"
-      " means no mpr algorithm (everyone is MPR), '"CFG_DOMAIN_ANY_MPR"' means"
-      " any metric that is loaded (with fallback on '"CFG_DOMAIN_NO_MPR"').",
+      "ID of the mpr algorithm used for this domain. '"CFG_DOMAIN_NO_METRIC_MPR"'"
+      " means no mpr algorithm (everyone is MPR), '"CFG_DOMAIN_ANY_METRIC_MPR"' means"
+      " any metric that is loaded (with fallback on '"CFG_DOMAIN_NO_METRIC_MPR"').",
       NHDP_DOMAIN_MPR_MAXLEN),
   CFG_MAP_INT32_MINMAX(_generic_parameters, mpr_willingness, "willingness",
       RFC7181_WILLINGNESS_DEFAULT_STRING,
@@ -134,15 +138,15 @@ static struct cfg_schema_section _interface_section = {
 };
 
 static struct cfg_schema_entry _domain_entries[] = {
-  CFG_MAP_STRING_ARRAY(_domain_parameters, metric_name, "metric", CFG_DOMAIN_ANY_METRIC,
-      "ID of the routing metric used for this domain. '"CFG_DOMAIN_NO_METRIC"'"
-      " means no metric (hopcount!), '"CFG_DOMAIN_ANY_METRIC"' means any metric"
-      " that is loaded (with fallback on '"CFG_DOMAIN_NO_METRIC"').",
+  CFG_MAP_STRING_ARRAY(_domain_parameters, metric_name, "metric", CFG_DOMAIN_ANY_METRIC_MPR,
+      "ID of the routing metric used for this domain. '"CFG_DOMAIN_NO_METRIC_MPR"'"
+      " means no metric (hopcount!), '"CFG_DOMAIN_ANY_METRIC_MPR"' means any metric"
+      " that is loaded (with fallback on '"CFG_DOMAIN_NO_METRIC_MPR"').",
       NHDP_DOMAIN_METRIC_MAXLEN),
-  CFG_MAP_STRING_ARRAY(_domain_parameters, mpr_name,  "mpr", CFG_DOMAIN_ANY_MPR,
-      "ID of the mpr algorithm used for this domain. '"CFG_DOMAIN_NO_MPR"'"
-      " means no mpr algorithm (everyone is MPR), '"CFG_DOMAIN_ANY_MPR"' means"
-      " any metric that is loaded (with fallback on '"CFG_DOMAIN_NO_MPR"').",
+  CFG_MAP_STRING_ARRAY(_domain_parameters, mpr_name,  "mpr", CFG_DOMAIN_ANY_METRIC_MPR,
+      "ID of the mpr algorithm used for this domain. '"CFG_DOMAIN_NO_METRIC_MPR"'"
+      " means no mpr algorithm (everyone is MPR), '"CFG_DOMAIN_ANY_METRIC_MPR"' means"
+      " any metric that is loaded (with fallback on '"CFG_DOMAIN_NO_METRIC_MPR"').",
       NHDP_DOMAIN_MPR_MAXLEN),
   CFG_MAP_INT32_MINMAX(_domain_parameters, mpr_willingness, "willingness",
       RFC7181_WILLINGNESS_DEFAULT_STRING, "Routing willingness used for MPR calculation",
@@ -208,13 +212,8 @@ _early_cfg_init(void) {
  */
 static int
 _init(void) {
-  _protocol = oonf_rfc5444_add_protocol(RFC5444_PROTOCOL, true);
-  if (_protocol == NULL) {
-    return -1;
-  }
-
+  _protocol = oonf_rfc5444_get_default_protocol();
   if (nhdp_writer_init(_protocol)) {
-    oonf_rfc5444_remove_protocol(_protocol);
     return -1;
   }
 
