@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
@@ -65,9 +69,17 @@
 /* Definitions */
 #define LOG_HTTP _oonf_http_subsystem.logging
 
+/**
+ * configuration of http plugin
+ */
 struct _http_config {
+  /*! http tcp configuration */
   struct oonf_stream_managed_config smc;
+
+  /*! directory for webserver functionality */
   char *www_dir;
+
+  /*! internal variable with file descriptor to webserver directory */
   int www_dir_fd;
 };
 /* HTTP text constants */
@@ -161,10 +173,10 @@ static struct oonf_stream_managed _http_managed_socket = {
   },
 };
 
-struct _http_config _config;
+static struct _http_config _config;
 
 /* integrated telnet/file handler */
-struct oonf_http_handler _telnet_handler = {
+static struct oonf_http_handler _telnet_handler = {
   .site = HTTP_TO_TELNET,
   .content_handler = _cb_telnet_handler,
   .acl = {
@@ -172,7 +184,7 @@ struct oonf_http_handler _telnet_handler = {
   },
 };
 
-struct oonf_http_handler _file_handler = {
+static struct oonf_http_handler _file_handler = {
   .site = HTTP_FILES,
   .content_handler = _cb_file_handler,
   .acl = {
@@ -186,7 +198,7 @@ static const char *_dependencies[] = {
   OONF_TELNET_SUBSYSTEM,
 };
 
-struct oonf_subsystem _oonf_http_subsystem = {
+static struct oonf_subsystem _oonf_http_subsystem = {
   .name = OONF_HTTP_SUBSYSTEM,
   .dependencies = _dependencies,
   .dependencies_count = ARRAYSIZE(_dependencies),
@@ -221,9 +233,11 @@ _cleanup(void) {
   if (_config.www_dir_fd != -1) {
     close(_config.www_dir_fd);
   }
+
   oonf_http_remove(&_telnet_handler);
   oonf_http_remove(&_file_handler);
   oonf_stream_remove_managed(&_http_managed_socket, true);
+  oonf_stream_free_managed_config(&_config.smc);
 }
 
 /**
@@ -407,7 +421,7 @@ _cb_receive_data(struct oonf_stream_session *session) {
     }
 
     if (result == HTTP_START_FILE_TRANSFER) {
-      session->copy_fd = header.transfer_fd;
+      os_fd_init(&session->copy_fd, header.transfer_fd);
       session->copy_total_size = header.transfer_length;
       session->copy_bytes_sent = 0;
 
@@ -432,9 +446,7 @@ _cb_receive_data(struct oonf_stream_session *session) {
  */
 static void
 _cb_cleanup_session(struct oonf_stream_session *session) {
-  if (session->copy_fd != -1) {
-    close(session->copy_fd);
-  }
+  os_fd_close(&session->copy_fd);
 }
 
 /**
